%global fontname terminus
%global fontconf 63-%{fontname}.conf

# Not using fontconfig for the legacy *.pcf.gz fonts
#global legacypcffontconf 63-#{fontname}-legacy-pcf.conf

# Not using fontconfig for the legacy *.bdf.gz fonts
#global legacypcffontconf 63-#{fontname}-legacy-bdf.conf


%global archivename terminus-font-%{version}


# This is the directory where we install our console fonts.
# Owned by the kbd package, which hardcodes it as /lib/kbd (without macros).
%global consolefontdir /lib/kbd/consolefonts


# The ExcludeArch from the grub2.spec file
#
# There might be a better way to detect whether this platform has
# grub2 available, but this should do the job at least for the time
# being.
%if 0%{?fedora} >= 29
%global grub2_exclude_arches s390 s390x
%else
%global grub2_exclude_arches s390 s390x %{arm}
%endif

# Owned by the grub2-common package
%global grub2fontdir   /usr/share/grub


# Font catalog
%global catalog %{_sysconfdir}/X11/fontpath.d


%global common_desc \
The Terminus Font is designed for long (8 and more hours per day)\
work with computers.\
\
It covers about 120 language sets and supports ISO8859-1/2/5/7/9/13/15/16,\
Paratype-PT154/PT254, KOI8-R/U/E/F, Esperanto, and many IBM, Windows and\
Macintosh code pages, as well as the IBM VGA, vt100 and xterm pseudo\
graphic characters.\
\
The sizes present are 6x12, 8x14, 8x16, 10x20, 11x22, 12x24, 14x28 and 16x32.\
The styles are normal and bold (except for 6x12),\
plus EGA/VGA-bold for 8x14 and 8x16.\
\
The font is available for the Linux console and for X11.


%if %{?epoch: 1}%{?!epoch: 0}
%global evr %{epoch}:%{version}-%{release}
%else
%global evr %{version}-%{release}
%endif

%global		_legacybdffontdir	%{_fontdir}-legacy-bdf
%global		_legacypcffontdir	%{_fontdir}-legacy-pcf

Name:		%{fontname}-fonts
Version:	4.48
Release:	2%{?dist}.1.4
Summary:	Clean fixed width font

# The source package also contains a few GPLv2+ build helper scripts.
License:	OFL
URL:		http://terminus-font.sourceforge.net/
Source0:	http://downloads.sourceforge.net/terminus-font/%{archivename}.tar.gz
Source1:	%{name}-fontconfig.conf
Source10:	%{name}-console.README.fedora
Source20:	%{name}.README.fedora
Source21:	%{name}.Xresources.example

Source42:	bitmapfonts2otb.py

Patch42:	terminus-font-opentype-bitmap-via-fontforge.patch

BuildArch:	noarch
BuildRequires:	fontpackages-devel >= 1.18
Requires:	fontpackages-filesystem

Obsoletes:	terminus-font-x11 < 4.28-2
Provides:	terminus-font-x11 = %{evr}

# For generating *.otb (OpenType bitmap font)
BuildRequires:	freetype-demos
BuildRequires:	xorg-x11-font-utils >= 1.1.0

BuildRequires:	python3 >= 3.5.0
BuildRequires:	/usr/bin/bdftopcf
BuildRequires:	/usr/bin/mkfontdir

%ifnarch %{grub2_exclude_arches}
BuildRequires:	/usr/bin/grub2-mkfont
%endif

%description
%common_desc

This package contains the OpenType bitmap fonts to use with
X11 and Wayland on Fedora 31 and later, and also the legacy
X11 PCF bitmap fonts for compatibility with older software.


%package console
Requires:	kbd
Summary:	Clean fixed width font (console version)
Obsoletes:	terminus-font-console < 4.28-2
Provides:	terminus-font-console = %{evr}
License:	OFL

%description console
%common_desc

This package contains the fonts to use with the Linux console.


%ifnarch %{grub2_exclude_arches}
%package grub2
Requires:	grub2-common
Summary:	Clean fixed width font (grub2 version)
License:	OFL

%description grub2
%common_desc

This package contains the fonts to use with the grub2 boot loader.
%endif


%package legacy-bdf
Summary:	Clean fixed width font (legacy BDF version for older X11 programs)
License:	OFL

%description legacy-bdf
%common_desc

This package contains the BDF fonts for older X11 programs.


%package legacy-pcf
Summary:	Clean fixed width font (legacy PCF version for older X11 programs)
License:	OFL

%description legacy-pcf
%common_desc

This package contains the PCF fonts for older X11 programs.


%prep
%setup -q -n %{archivename}
#patch42 -p1 -b .opentype-bitmap-via-fontforge
patch -s -p1 -b --suffix .dv1 -fuzz=0 -i alt/dv1.diff
patch -s -p1 -b --suffix .ij1 -fuzz=0 -i alt/ij1.diff
chmod 755 configure
iconv -f WINDOWS-1251 -t utf-8 -o README-BG README-BG


%build
# The libdir is just to shut up rpmlint. Configure is nice enough to
# just ignore it.
./configure --prefix=%{_prefix} --libdir=%{_libdir} \
	--x11dir=%{_legacypcffontdir} --psfdir=%{consolefontdir}
env GZIP=--best make %{?_smp_mflags} PCF='$(PCF_10646_1) $(PCF_8BIT)' pcf psf psf-vgaw

%ifnarch %{grub2_exclude_arches}
# generate *.pf2 for the grub2 bootloader
for bdf in ter-*[bn].bdf; do
  /usr/bin/grub2-mkfont -o "$(basename "$bdf" .bdf).pf2" "$bdf"
done
%endif

python3 "%{SOURCE42}" ter-*[bn].bdf
ls -l *.otb

# Fedora specific docs and examples
mkdir -p docs/console docs/x11
cp -p "%{SOURCE10}" docs/console/README.fedora
cp -p "%{SOURCE20}" docs/x11/README.fedora
cp -p "%{SOURCE21}" docs/x11/Xresources.example


%install
make DESTDIR="%{buildroot}" PCF='$(PCF_10646_1) $(PCF_8BIT)' install-psf install-psf-ref install-psf-vgaw install-pcf

%ifnarch %{grub2_exclude_arches}
# install *.pf2 for the grub2 bootloader
install -m 0755 -d %{buildroot}%{grub2fontdir}
install -m 0644 -t %{buildroot}%{grub2fontdir} ter-*.pf2
%endif

# hook the OTB fonts into fontconfig
install -m 0755 -d \
	%{buildroot}%{_fontconfig_templatedir} \
	%{buildroot}%{_fontconfig_confdir}

install -m 0644 -p %{SOURCE1} \
	%{buildroot}%{_fontconfig_templatedir}/%{fontconf}
ln -s \
	%{_fontconfig_templatedir}/%{fontconf} \
	%{buildroot}%{_fontconfig_confdir}/%{fontconf}

install -m 0755 -d %{buildroot}%{_fontdir}
install -m 0644 -t %{buildroot}%{_fontdir} Terminus.otb Terminus-Bold.otb

# We cannot run mkfontdir in %%post because %%post is generated by %%_font_pkg
/usr/bin/mkfontdir %{buildroot}%{_fontdir}

# hook the legacy X11 fonts into fontconfig as well

#install -m 0644 -p %{SOURCE1} \
#	%{buildroot}%{_fontconfig_templatedir}/%{legacypcffontconf}
#ln -s \
#	%{_fontconfig_templatedir}/%{legacypcffontconf} \
#	%{buildroot}%{_fontconfig_confdir}/%{legacypcffontconf}

# We cannot run mkfontdir in %%post because %%post is generated by %%_font_pkg
install -m 0755 -d %{buildroot}%{catalog}
ln -s %{_legacypcffontdir} %{buildroot}%{catalog}/%{fontname}:unscaled
/usr/bin/mkfontdir %{buildroot}%{_legacypcffontdir}

# Install and hook the BDF fonts into font magic
install -m 0755 -d %{buildroot}%{_legacybdffontdir}
install -m 0644 -t %{buildroot}%{_legacybdffontdir} ter-*[bn].bdf
/usr/bin/mkfontdir %{buildroot}%{_legacybdffontdir}


%_font_pkg -f %{fontconf} Terminus.otb Terminus-Bold.otb
%doc README
%doc README-BG
%doc docs/x11/README.fedora
%{_fontdir}/fonts.dir


%files legacy-bdf
# Replicate the workings of _font_pkg, as that macro does not work
# for shipping a second package with legacy font formats.
%doc README
%doc README-BG
%doc docs/x11/README.fedora
%doc docs/x11/Xresources.example
%dir %{_legacypcffontdir}
%ghost %{_legacypcffontdir}/.uuid
%{_legacybdffontdir}/fonts.dir
%{_legacybdffontdir}/ter-u12b.bdf
%{_legacybdffontdir}/ter-u12n.bdf
%{_legacybdffontdir}/ter-u14b.bdf
%{_legacybdffontdir}/ter-u14n.bdf
%{_legacybdffontdir}/ter-u16b.bdf
%{_legacybdffontdir}/ter-u16n.bdf
%{_legacybdffontdir}/ter-u18b.bdf
%{_legacybdffontdir}/ter-u18n.bdf
%{_legacybdffontdir}/ter-u20b.bdf
%{_legacybdffontdir}/ter-u20n.bdf
%{_legacybdffontdir}/ter-u22b.bdf
%{_legacybdffontdir}/ter-u22n.bdf
%{_legacybdffontdir}/ter-u24b.bdf
%{_legacybdffontdir}/ter-u24n.bdf
%{_legacybdffontdir}/ter-u28b.bdf
%{_legacybdffontdir}/ter-u28n.bdf
%{_legacybdffontdir}/ter-u32b.bdf
%{_legacybdffontdir}/ter-u32n.bdf


%files legacy-pcf
# Replicate the workings of _font_pkg, as that macro does not work
# for shipping a second package with legacy font formats.
%doc README
%doc README-BG
%doc docs/x11/README.fedora
%doc docs/x11/Xresources.example
%dir %{_legacypcffontdir}
%ghost %{_legacypcffontdir}/.uuid
%{catalog}/%{fontname}:unscaled
%{_legacypcffontdir}/fonts.dir
#{_fontconfig_templatedir}/%{legacypcffontconf}
#config(noreplace) %{_fontconfig_confdir}/%{legacypcffontconf}
%{_legacypcffontdir}/ter-112b.pcf.gz
%{_legacypcffontdir}/ter-112n.pcf.gz
%{_legacypcffontdir}/ter-114b.pcf.gz
%{_legacypcffontdir}/ter-114n.pcf.gz
%{_legacypcffontdir}/ter-116b.pcf.gz
%{_legacypcffontdir}/ter-116n.pcf.gz
%{_legacypcffontdir}/ter-118b.pcf.gz
%{_legacypcffontdir}/ter-118n.pcf.gz
%{_legacypcffontdir}/ter-120b.pcf.gz
%{_legacypcffontdir}/ter-120n.pcf.gz
%{_legacypcffontdir}/ter-122b.pcf.gz
%{_legacypcffontdir}/ter-122n.pcf.gz
%{_legacypcffontdir}/ter-124b.pcf.gz
%{_legacypcffontdir}/ter-124n.pcf.gz
%{_legacypcffontdir}/ter-128b.pcf.gz
%{_legacypcffontdir}/ter-128n.pcf.gz
%{_legacypcffontdir}/ter-132b.pcf.gz
%{_legacypcffontdir}/ter-132n.pcf.gz
%{_legacypcffontdir}/ter-212b.pcf.gz
%{_legacypcffontdir}/ter-212n.pcf.gz
%{_legacypcffontdir}/ter-214b.pcf.gz
%{_legacypcffontdir}/ter-214n.pcf.gz
%{_legacypcffontdir}/ter-216b.pcf.gz
%{_legacypcffontdir}/ter-216n.pcf.gz
%{_legacypcffontdir}/ter-218b.pcf.gz
%{_legacypcffontdir}/ter-218n.pcf.gz
%{_legacypcffontdir}/ter-220b.pcf.gz
%{_legacypcffontdir}/ter-220n.pcf.gz
%{_legacypcffontdir}/ter-222b.pcf.gz
%{_legacypcffontdir}/ter-222n.pcf.gz
%{_legacypcffontdir}/ter-224b.pcf.gz
%{_legacypcffontdir}/ter-224n.pcf.gz
%{_legacypcffontdir}/ter-228b.pcf.gz
%{_legacypcffontdir}/ter-228n.pcf.gz
%{_legacypcffontdir}/ter-232b.pcf.gz
%{_legacypcffontdir}/ter-232n.pcf.gz
%{_legacypcffontdir}/ter-512b.pcf.gz
%{_legacypcffontdir}/ter-512n.pcf.gz
%{_legacypcffontdir}/ter-514b.pcf.gz
%{_legacypcffontdir}/ter-514n.pcf.gz
%{_legacypcffontdir}/ter-516b.pcf.gz
%{_legacypcffontdir}/ter-516n.pcf.gz
%{_legacypcffontdir}/ter-518b.pcf.gz
%{_legacypcffontdir}/ter-518n.pcf.gz
%{_legacypcffontdir}/ter-520b.pcf.gz
%{_legacypcffontdir}/ter-520n.pcf.gz
%{_legacypcffontdir}/ter-522b.pcf.gz
%{_legacypcffontdir}/ter-522n.pcf.gz
%{_legacypcffontdir}/ter-524b.pcf.gz
%{_legacypcffontdir}/ter-524n.pcf.gz
%{_legacypcffontdir}/ter-528b.pcf.gz
%{_legacypcffontdir}/ter-528n.pcf.gz
%{_legacypcffontdir}/ter-532b.pcf.gz
%{_legacypcffontdir}/ter-532n.pcf.gz
%{_legacypcffontdir}/ter-712b.pcf.gz
%{_legacypcffontdir}/ter-712n.pcf.gz
%{_legacypcffontdir}/ter-714b.pcf.gz
%{_legacypcffontdir}/ter-714n.pcf.gz
%{_legacypcffontdir}/ter-716b.pcf.gz
%{_legacypcffontdir}/ter-716n.pcf.gz
%{_legacypcffontdir}/ter-718b.pcf.gz
%{_legacypcffontdir}/ter-718n.pcf.gz
%{_legacypcffontdir}/ter-720b.pcf.gz
%{_legacypcffontdir}/ter-720n.pcf.gz
%{_legacypcffontdir}/ter-722b.pcf.gz
%{_legacypcffontdir}/ter-722n.pcf.gz
%{_legacypcffontdir}/ter-724b.pcf.gz
%{_legacypcffontdir}/ter-724n.pcf.gz
%{_legacypcffontdir}/ter-728b.pcf.gz
%{_legacypcffontdir}/ter-728n.pcf.gz
%{_legacypcffontdir}/ter-732b.pcf.gz
%{_legacypcffontdir}/ter-732n.pcf.gz
%{_legacypcffontdir}/ter-912b.pcf.gz
%{_legacypcffontdir}/ter-912n.pcf.gz
%{_legacypcffontdir}/ter-914b.pcf.gz
%{_legacypcffontdir}/ter-914n.pcf.gz
%{_legacypcffontdir}/ter-916b.pcf.gz
%{_legacypcffontdir}/ter-916n.pcf.gz
%{_legacypcffontdir}/ter-918b.pcf.gz
%{_legacypcffontdir}/ter-918n.pcf.gz
%{_legacypcffontdir}/ter-920b.pcf.gz
%{_legacypcffontdir}/ter-920n.pcf.gz
%{_legacypcffontdir}/ter-922b.pcf.gz
%{_legacypcffontdir}/ter-922n.pcf.gz
%{_legacypcffontdir}/ter-924b.pcf.gz
%{_legacypcffontdir}/ter-924n.pcf.gz
%{_legacypcffontdir}/ter-928b.pcf.gz
%{_legacypcffontdir}/ter-928n.pcf.gz
%{_legacypcffontdir}/ter-932b.pcf.gz
%{_legacypcffontdir}/ter-932n.pcf.gz
%{_legacypcffontdir}/ter-c12b.pcf.gz
%{_legacypcffontdir}/ter-c12n.pcf.gz
%{_legacypcffontdir}/ter-c14b.pcf.gz
%{_legacypcffontdir}/ter-c14n.pcf.gz
%{_legacypcffontdir}/ter-c16b.pcf.gz
%{_legacypcffontdir}/ter-c16n.pcf.gz
%{_legacypcffontdir}/ter-c18b.pcf.gz
%{_legacypcffontdir}/ter-c18n.pcf.gz
%{_legacypcffontdir}/ter-c20b.pcf.gz
%{_legacypcffontdir}/ter-c20n.pcf.gz
%{_legacypcffontdir}/ter-c22b.pcf.gz
%{_legacypcffontdir}/ter-c22n.pcf.gz
%{_legacypcffontdir}/ter-c24b.pcf.gz
%{_legacypcffontdir}/ter-c24n.pcf.gz
%{_legacypcffontdir}/ter-c28b.pcf.gz
%{_legacypcffontdir}/ter-c28n.pcf.gz
%{_legacypcffontdir}/ter-c32b.pcf.gz
%{_legacypcffontdir}/ter-c32n.pcf.gz
%{_legacypcffontdir}/ter-d12b.pcf.gz
%{_legacypcffontdir}/ter-d12n.pcf.gz
%{_legacypcffontdir}/ter-d14b.pcf.gz
%{_legacypcffontdir}/ter-d14n.pcf.gz
%{_legacypcffontdir}/ter-d16b.pcf.gz
%{_legacypcffontdir}/ter-d16n.pcf.gz
%{_legacypcffontdir}/ter-d18b.pcf.gz
%{_legacypcffontdir}/ter-d18n.pcf.gz
%{_legacypcffontdir}/ter-d20b.pcf.gz
%{_legacypcffontdir}/ter-d20n.pcf.gz
%{_legacypcffontdir}/ter-d22b.pcf.gz
%{_legacypcffontdir}/ter-d22n.pcf.gz
%{_legacypcffontdir}/ter-d24b.pcf.gz
%{_legacypcffontdir}/ter-d24n.pcf.gz
%{_legacypcffontdir}/ter-d28b.pcf.gz
%{_legacypcffontdir}/ter-d28n.pcf.gz
%{_legacypcffontdir}/ter-d32b.pcf.gz
%{_legacypcffontdir}/ter-d32n.pcf.gz
%{_legacypcffontdir}/ter-f12b.pcf.gz
%{_legacypcffontdir}/ter-f12n.pcf.gz
%{_legacypcffontdir}/ter-f14b.pcf.gz
%{_legacypcffontdir}/ter-f14n.pcf.gz
%{_legacypcffontdir}/ter-f16b.pcf.gz
%{_legacypcffontdir}/ter-f16n.pcf.gz
%{_legacypcffontdir}/ter-f18b.pcf.gz
%{_legacypcffontdir}/ter-f18n.pcf.gz
%{_legacypcffontdir}/ter-f20b.pcf.gz
%{_legacypcffontdir}/ter-f20n.pcf.gz
%{_legacypcffontdir}/ter-f22b.pcf.gz
%{_legacypcffontdir}/ter-f22n.pcf.gz
%{_legacypcffontdir}/ter-f24b.pcf.gz
%{_legacypcffontdir}/ter-f24n.pcf.gz
%{_legacypcffontdir}/ter-f28b.pcf.gz
%{_legacypcffontdir}/ter-f28n.pcf.gz
%{_legacypcffontdir}/ter-f32b.pcf.gz
%{_legacypcffontdir}/ter-f32n.pcf.gz
%{_legacypcffontdir}/ter-g12b.pcf.gz
%{_legacypcffontdir}/ter-g12n.pcf.gz
%{_legacypcffontdir}/ter-g14b.pcf.gz
%{_legacypcffontdir}/ter-g14n.pcf.gz
%{_legacypcffontdir}/ter-g16b.pcf.gz
%{_legacypcffontdir}/ter-g16n.pcf.gz
%{_legacypcffontdir}/ter-g18b.pcf.gz
%{_legacypcffontdir}/ter-g18n.pcf.gz
%{_legacypcffontdir}/ter-g20b.pcf.gz
%{_legacypcffontdir}/ter-g20n.pcf.gz
%{_legacypcffontdir}/ter-g22b.pcf.gz
%{_legacypcffontdir}/ter-g22n.pcf.gz
%{_legacypcffontdir}/ter-g24b.pcf.gz
%{_legacypcffontdir}/ter-g24n.pcf.gz
%{_legacypcffontdir}/ter-g28b.pcf.gz
%{_legacypcffontdir}/ter-g28n.pcf.gz
%{_legacypcffontdir}/ter-g32b.pcf.gz
%{_legacypcffontdir}/ter-g32n.pcf.gz
%{_legacypcffontdir}/ter-i12b.pcf.gz
%{_legacypcffontdir}/ter-i12n.pcf.gz
%{_legacypcffontdir}/ter-i14b.pcf.gz
%{_legacypcffontdir}/ter-i14n.pcf.gz
%{_legacypcffontdir}/ter-i16b.pcf.gz
%{_legacypcffontdir}/ter-i16n.pcf.gz
%{_legacypcffontdir}/ter-i18b.pcf.gz
%{_legacypcffontdir}/ter-i18n.pcf.gz
%{_legacypcffontdir}/ter-i20b.pcf.gz
%{_legacypcffontdir}/ter-i20n.pcf.gz
%{_legacypcffontdir}/ter-i22b.pcf.gz
%{_legacypcffontdir}/ter-i22n.pcf.gz
%{_legacypcffontdir}/ter-i24b.pcf.gz
%{_legacypcffontdir}/ter-i24n.pcf.gz
%{_legacypcffontdir}/ter-i28b.pcf.gz
%{_legacypcffontdir}/ter-i28n.pcf.gz
%{_legacypcffontdir}/ter-i32b.pcf.gz
%{_legacypcffontdir}/ter-i32n.pcf.gz
%{_legacypcffontdir}/ter-k12b.pcf.gz
%{_legacypcffontdir}/ter-k12n.pcf.gz
%{_legacypcffontdir}/ter-k14b.pcf.gz
%{_legacypcffontdir}/ter-k14n.pcf.gz
%{_legacypcffontdir}/ter-k16b.pcf.gz
%{_legacypcffontdir}/ter-k16n.pcf.gz
%{_legacypcffontdir}/ter-k18b.pcf.gz
%{_legacypcffontdir}/ter-k18n.pcf.gz
%{_legacypcffontdir}/ter-k20b.pcf.gz
%{_legacypcffontdir}/ter-k20n.pcf.gz
%{_legacypcffontdir}/ter-k22b.pcf.gz
%{_legacypcffontdir}/ter-k22n.pcf.gz
%{_legacypcffontdir}/ter-k24b.pcf.gz
%{_legacypcffontdir}/ter-k24n.pcf.gz
%{_legacypcffontdir}/ter-k28b.pcf.gz
%{_legacypcffontdir}/ter-k28n.pcf.gz
%{_legacypcffontdir}/ter-k32b.pcf.gz
%{_legacypcffontdir}/ter-k32n.pcf.gz
%{_legacypcffontdir}/ter-p12b.pcf.gz
%{_legacypcffontdir}/ter-p12n.pcf.gz
%{_legacypcffontdir}/ter-p14b.pcf.gz
%{_legacypcffontdir}/ter-p14n.pcf.gz
%{_legacypcffontdir}/ter-p16b.pcf.gz
%{_legacypcffontdir}/ter-p16n.pcf.gz
%{_legacypcffontdir}/ter-p18b.pcf.gz
%{_legacypcffontdir}/ter-p18n.pcf.gz
%{_legacypcffontdir}/ter-p20b.pcf.gz
%{_legacypcffontdir}/ter-p20n.pcf.gz
%{_legacypcffontdir}/ter-p22b.pcf.gz
%{_legacypcffontdir}/ter-p22n.pcf.gz
%{_legacypcffontdir}/ter-p24b.pcf.gz
%{_legacypcffontdir}/ter-p24n.pcf.gz
%{_legacypcffontdir}/ter-p28b.pcf.gz
%{_legacypcffontdir}/ter-p28n.pcf.gz
%{_legacypcffontdir}/ter-p32b.pcf.gz
%{_legacypcffontdir}/ter-p32n.pcf.gz
%{_legacypcffontdir}/ter-u12b.pcf.gz
%{_legacypcffontdir}/ter-u12n.pcf.gz
%{_legacypcffontdir}/ter-u14b.pcf.gz
%{_legacypcffontdir}/ter-u14n.pcf.gz
%{_legacypcffontdir}/ter-u16b.pcf.gz
%{_legacypcffontdir}/ter-u16n.pcf.gz
%{_legacypcffontdir}/ter-u18b.pcf.gz
%{_legacypcffontdir}/ter-u18n.pcf.gz
%{_legacypcffontdir}/ter-u20b.pcf.gz
%{_legacypcffontdir}/ter-u20n.pcf.gz
%{_legacypcffontdir}/ter-u22b.pcf.gz
%{_legacypcffontdir}/ter-u22n.pcf.gz
%{_legacypcffontdir}/ter-u24b.pcf.gz
%{_legacypcffontdir}/ter-u24n.pcf.gz
%{_legacypcffontdir}/ter-u28b.pcf.gz
%{_legacypcffontdir}/ter-u28n.pcf.gz
%{_legacypcffontdir}/ter-u32b.pcf.gz
%{_legacypcffontdir}/ter-u32n.pcf.gz
%{_legacypcffontdir}/ter-x12b.pcf.gz
%{_legacypcffontdir}/ter-x12n.pcf.gz
%{_legacypcffontdir}/ter-x14b.pcf.gz
%{_legacypcffontdir}/ter-x14n.pcf.gz
%{_legacypcffontdir}/ter-x16b.pcf.gz
%{_legacypcffontdir}/ter-x16n.pcf.gz
%{_legacypcffontdir}/ter-x18b.pcf.gz
%{_legacypcffontdir}/ter-x18n.pcf.gz
%{_legacypcffontdir}/ter-x20b.pcf.gz
%{_legacypcffontdir}/ter-x20n.pcf.gz
%{_legacypcffontdir}/ter-x22b.pcf.gz
%{_legacypcffontdir}/ter-x22n.pcf.gz
%{_legacypcffontdir}/ter-x24b.pcf.gz
%{_legacypcffontdir}/ter-x24n.pcf.gz
%{_legacypcffontdir}/ter-x28b.pcf.gz
%{_legacypcffontdir}/ter-x28n.pcf.gz
%{_legacypcffontdir}/ter-x32b.pcf.gz
%{_legacypcffontdir}/ter-x32n.pcf.gz


%files console
%doc README
%doc README-BG
%doc docs/console/README.fedora
%doc %{consolefontdir}/README.terminus
# VGAW fonts
%{consolefontdir}/ter-114v.psf.gz
%{consolefontdir}/ter-116v.psf.gz
%{consolefontdir}/ter-214v.psf.gz
%{consolefontdir}/ter-216v.psf.gz
%{consolefontdir}/ter-714v.psf.gz
%{consolefontdir}/ter-716v.psf.gz
%{consolefontdir}/ter-914v.psf.gz
%{consolefontdir}/ter-916v.psf.gz
%{consolefontdir}/ter-c14v.psf.gz
%{consolefontdir}/ter-c16v.psf.gz
%{consolefontdir}/ter-d14v.psf.gz
%{consolefontdir}/ter-d16v.psf.gz
%{consolefontdir}/ter-g14v.psf.gz
%{consolefontdir}/ter-g16v.psf.gz
%{consolefontdir}/ter-h14v.psf.gz
%{consolefontdir}/ter-h16v.psf.gz
%{consolefontdir}/ter-i14v.psf.gz
%{consolefontdir}/ter-i16v.psf.gz
%{consolefontdir}/ter-k14v.psf.gz
%{consolefontdir}/ter-k16v.psf.gz
%{consolefontdir}/ter-m14v.psf.gz
%{consolefontdir}/ter-m16v.psf.gz
%{consolefontdir}/ter-p14v.psf.gz
%{consolefontdir}/ter-p16v.psf.gz
%{consolefontdir}/ter-u14v.psf.gz
%{consolefontdir}/ter-u16v.psf.gz
%{consolefontdir}/ter-v14v.psf.gz
%{consolefontdir}/ter-v16v.psf.gz
# normal and bold (non-VGAW specific) fonts
%{consolefontdir}/ter-112n.psf.gz
%{consolefontdir}/ter-114b.psf.gz
%{consolefontdir}/ter-114n.psf.gz
%{consolefontdir}/ter-116b.psf.gz
%{consolefontdir}/ter-116n.psf.gz
%{consolefontdir}/ter-118b.psf.gz
%{consolefontdir}/ter-118n.psf.gz
%{consolefontdir}/ter-120b.psf.gz
%{consolefontdir}/ter-120n.psf.gz
%{consolefontdir}/ter-122b.psf.gz
%{consolefontdir}/ter-122n.psf.gz
%{consolefontdir}/ter-124b.psf.gz
%{consolefontdir}/ter-124n.psf.gz
%{consolefontdir}/ter-128b.psf.gz
%{consolefontdir}/ter-128n.psf.gz
%{consolefontdir}/ter-132b.psf.gz
%{consolefontdir}/ter-132n.psf.gz
%{consolefontdir}/ter-212n.psf.gz
%{consolefontdir}/ter-214b.psf.gz
%{consolefontdir}/ter-214n.psf.gz
%{consolefontdir}/ter-216b.psf.gz
%{consolefontdir}/ter-216n.psf.gz
%{consolefontdir}/ter-218b.psf.gz
%{consolefontdir}/ter-218n.psf.gz
%{consolefontdir}/ter-220b.psf.gz
%{consolefontdir}/ter-220n.psf.gz
%{consolefontdir}/ter-222b.psf.gz
%{consolefontdir}/ter-222n.psf.gz
%{consolefontdir}/ter-224b.psf.gz
%{consolefontdir}/ter-224n.psf.gz
%{consolefontdir}/ter-228b.psf.gz
%{consolefontdir}/ter-228n.psf.gz
%{consolefontdir}/ter-232b.psf.gz
%{consolefontdir}/ter-232n.psf.gz
%{consolefontdir}/ter-712n.psf.gz
%{consolefontdir}/ter-714b.psf.gz
%{consolefontdir}/ter-714n.psf.gz
%{consolefontdir}/ter-716b.psf.gz
%{consolefontdir}/ter-716n.psf.gz
%{consolefontdir}/ter-718b.psf.gz
%{consolefontdir}/ter-718n.psf.gz
%{consolefontdir}/ter-720b.psf.gz
%{consolefontdir}/ter-720n.psf.gz
%{consolefontdir}/ter-722b.psf.gz
%{consolefontdir}/ter-722n.psf.gz
%{consolefontdir}/ter-724b.psf.gz
%{consolefontdir}/ter-724n.psf.gz
%{consolefontdir}/ter-728b.psf.gz
%{consolefontdir}/ter-728n.psf.gz
%{consolefontdir}/ter-732b.psf.gz
%{consolefontdir}/ter-732n.psf.gz
%{consolefontdir}/ter-912n.psf.gz
%{consolefontdir}/ter-914b.psf.gz
%{consolefontdir}/ter-914n.psf.gz
%{consolefontdir}/ter-916b.psf.gz
%{consolefontdir}/ter-916n.psf.gz
%{consolefontdir}/ter-918b.psf.gz
%{consolefontdir}/ter-918n.psf.gz
%{consolefontdir}/ter-920b.psf.gz
%{consolefontdir}/ter-920n.psf.gz
%{consolefontdir}/ter-922b.psf.gz
%{consolefontdir}/ter-922n.psf.gz
%{consolefontdir}/ter-924b.psf.gz
%{consolefontdir}/ter-924n.psf.gz
%{consolefontdir}/ter-928b.psf.gz
%{consolefontdir}/ter-928n.psf.gz
%{consolefontdir}/ter-932b.psf.gz
%{consolefontdir}/ter-932n.psf.gz
%{consolefontdir}/ter-c12n.psf.gz
%{consolefontdir}/ter-c14b.psf.gz
%{consolefontdir}/ter-c14n.psf.gz
%{consolefontdir}/ter-c16b.psf.gz
%{consolefontdir}/ter-c16n.psf.gz
%{consolefontdir}/ter-c18b.psf.gz
%{consolefontdir}/ter-c18n.psf.gz
%{consolefontdir}/ter-c20b.psf.gz
%{consolefontdir}/ter-c20n.psf.gz
%{consolefontdir}/ter-c22b.psf.gz
%{consolefontdir}/ter-c22n.psf.gz
%{consolefontdir}/ter-c24b.psf.gz
%{consolefontdir}/ter-c24n.psf.gz
%{consolefontdir}/ter-c28b.psf.gz
%{consolefontdir}/ter-c28n.psf.gz
%{consolefontdir}/ter-c32b.psf.gz
%{consolefontdir}/ter-c32n.psf.gz
%{consolefontdir}/ter-d12n.psf.gz
%{consolefontdir}/ter-d14b.psf.gz
%{consolefontdir}/ter-d14n.psf.gz
%{consolefontdir}/ter-d16b.psf.gz
%{consolefontdir}/ter-d16n.psf.gz
%{consolefontdir}/ter-d18b.psf.gz
%{consolefontdir}/ter-d18n.psf.gz
%{consolefontdir}/ter-d20b.psf.gz
%{consolefontdir}/ter-d20n.psf.gz
%{consolefontdir}/ter-d22b.psf.gz
%{consolefontdir}/ter-d22n.psf.gz
%{consolefontdir}/ter-d24b.psf.gz
%{consolefontdir}/ter-d24n.psf.gz
%{consolefontdir}/ter-d28b.psf.gz
%{consolefontdir}/ter-d28n.psf.gz
%{consolefontdir}/ter-d32b.psf.gz
%{consolefontdir}/ter-d32n.psf.gz
%{consolefontdir}/ter-g12n.psf.gz
%{consolefontdir}/ter-g14b.psf.gz
%{consolefontdir}/ter-g14n.psf.gz
%{consolefontdir}/ter-g16b.psf.gz
%{consolefontdir}/ter-g16n.psf.gz
%{consolefontdir}/ter-g18b.psf.gz
%{consolefontdir}/ter-g18n.psf.gz
%{consolefontdir}/ter-g20b.psf.gz
%{consolefontdir}/ter-g20n.psf.gz
%{consolefontdir}/ter-g22b.psf.gz
%{consolefontdir}/ter-g22n.psf.gz
%{consolefontdir}/ter-g24b.psf.gz
%{consolefontdir}/ter-g24n.psf.gz
%{consolefontdir}/ter-g28b.psf.gz
%{consolefontdir}/ter-g28n.psf.gz
%{consolefontdir}/ter-g32b.psf.gz
%{consolefontdir}/ter-g32n.psf.gz
%{consolefontdir}/ter-h12n.psf.gz
%{consolefontdir}/ter-h14b.psf.gz
%{consolefontdir}/ter-h14n.psf.gz
%{consolefontdir}/ter-h16b.psf.gz
%{consolefontdir}/ter-h16n.psf.gz
%{consolefontdir}/ter-h18b.psf.gz
%{consolefontdir}/ter-h18n.psf.gz
%{consolefontdir}/ter-h20b.psf.gz
%{consolefontdir}/ter-h20n.psf.gz
%{consolefontdir}/ter-h22b.psf.gz
%{consolefontdir}/ter-h22n.psf.gz
%{consolefontdir}/ter-h24b.psf.gz
%{consolefontdir}/ter-h24n.psf.gz
%{consolefontdir}/ter-h28b.psf.gz
%{consolefontdir}/ter-h28n.psf.gz
%{consolefontdir}/ter-h32b.psf.gz
%{consolefontdir}/ter-h32n.psf.gz
%{consolefontdir}/ter-i12n.psf.gz
%{consolefontdir}/ter-i14b.psf.gz
%{consolefontdir}/ter-i14n.psf.gz
%{consolefontdir}/ter-i16b.psf.gz
%{consolefontdir}/ter-i16n.psf.gz
%{consolefontdir}/ter-i18b.psf.gz
%{consolefontdir}/ter-i18n.psf.gz
%{consolefontdir}/ter-i20b.psf.gz
%{consolefontdir}/ter-i20n.psf.gz
%{consolefontdir}/ter-i22b.psf.gz
%{consolefontdir}/ter-i22n.psf.gz
%{consolefontdir}/ter-i24b.psf.gz
%{consolefontdir}/ter-i24n.psf.gz
%{consolefontdir}/ter-i28b.psf.gz
%{consolefontdir}/ter-i28n.psf.gz
%{consolefontdir}/ter-i32b.psf.gz
%{consolefontdir}/ter-i32n.psf.gz
%{consolefontdir}/ter-k12n.psf.gz
%{consolefontdir}/ter-k14b.psf.gz
%{consolefontdir}/ter-k14n.psf.gz
%{consolefontdir}/ter-k16b.psf.gz
%{consolefontdir}/ter-k16n.psf.gz
%{consolefontdir}/ter-k18b.psf.gz
%{consolefontdir}/ter-k18n.psf.gz
%{consolefontdir}/ter-k20b.psf.gz
%{consolefontdir}/ter-k20n.psf.gz
%{consolefontdir}/ter-k22b.psf.gz
%{consolefontdir}/ter-k22n.psf.gz
%{consolefontdir}/ter-k24b.psf.gz
%{consolefontdir}/ter-k24n.psf.gz
%{consolefontdir}/ter-k28b.psf.gz
%{consolefontdir}/ter-k28n.psf.gz
%{consolefontdir}/ter-k32b.psf.gz
%{consolefontdir}/ter-k32n.psf.gz
%{consolefontdir}/ter-m12n.psf.gz
%{consolefontdir}/ter-m14b.psf.gz
%{consolefontdir}/ter-m14n.psf.gz
%{consolefontdir}/ter-m16b.psf.gz
%{consolefontdir}/ter-m16n.psf.gz
%{consolefontdir}/ter-m18b.psf.gz
%{consolefontdir}/ter-m18n.psf.gz
%{consolefontdir}/ter-m20b.psf.gz
%{consolefontdir}/ter-m20n.psf.gz
%{consolefontdir}/ter-m22b.psf.gz
%{consolefontdir}/ter-m22n.psf.gz
%{consolefontdir}/ter-m24b.psf.gz
%{consolefontdir}/ter-m24n.psf.gz
%{consolefontdir}/ter-m28b.psf.gz
%{consolefontdir}/ter-m28n.psf.gz
%{consolefontdir}/ter-m32b.psf.gz
%{consolefontdir}/ter-m32n.psf.gz
%{consolefontdir}/ter-p12n.psf.gz
%{consolefontdir}/ter-p14b.psf.gz
%{consolefontdir}/ter-p14n.psf.gz
%{consolefontdir}/ter-p16b.psf.gz
%{consolefontdir}/ter-p16n.psf.gz
%{consolefontdir}/ter-p18b.psf.gz
%{consolefontdir}/ter-p18n.psf.gz
%{consolefontdir}/ter-p20b.psf.gz
%{consolefontdir}/ter-p20n.psf.gz
%{consolefontdir}/ter-p22b.psf.gz
%{consolefontdir}/ter-p22n.psf.gz
%{consolefontdir}/ter-p24b.psf.gz
%{consolefontdir}/ter-p24n.psf.gz
%{consolefontdir}/ter-p28b.psf.gz
%{consolefontdir}/ter-p28n.psf.gz
%{consolefontdir}/ter-p32b.psf.gz
%{consolefontdir}/ter-p32n.psf.gz
%{consolefontdir}/ter-u12n.psf.gz
%{consolefontdir}/ter-u14b.psf.gz
%{consolefontdir}/ter-u14n.psf.gz
%{consolefontdir}/ter-u16b.psf.gz
%{consolefontdir}/ter-u16n.psf.gz
%{consolefontdir}/ter-u18b.psf.gz
%{consolefontdir}/ter-u18n.psf.gz
%{consolefontdir}/ter-u20b.psf.gz
%{consolefontdir}/ter-u20n.psf.gz
%{consolefontdir}/ter-u22b.psf.gz
%{consolefontdir}/ter-u22n.psf.gz
%{consolefontdir}/ter-u24b.psf.gz
%{consolefontdir}/ter-u24n.psf.gz
%{consolefontdir}/ter-u28b.psf.gz
%{consolefontdir}/ter-u28n.psf.gz
%{consolefontdir}/ter-u32b.psf.gz
%{consolefontdir}/ter-u32n.psf.gz
%{consolefontdir}/ter-v12n.psf.gz
%{consolefontdir}/ter-v14b.psf.gz
%{consolefontdir}/ter-v14n.psf.gz
%{consolefontdir}/ter-v16b.psf.gz
%{consolefontdir}/ter-v16n.psf.gz
%{consolefontdir}/ter-v18b.psf.gz
%{consolefontdir}/ter-v18n.psf.gz
%{consolefontdir}/ter-v20b.psf.gz
%{consolefontdir}/ter-v20n.psf.gz
%{consolefontdir}/ter-v22b.psf.gz
%{consolefontdir}/ter-v22n.psf.gz
%{consolefontdir}/ter-v24b.psf.gz
%{consolefontdir}/ter-v24n.psf.gz
%{consolefontdir}/ter-v28b.psf.gz
%{consolefontdir}/ter-v28n.psf.gz
%{consolefontdir}/ter-v32b.psf.gz
%{consolefontdir}/ter-v32n.psf.gz


%ifnarch %{grub2_exclude_arches}
%files grub2
%doc README README-BG
%{grub2fontdir}/ter-u12b.pf2
%{grub2fontdir}/ter-u12n.pf2
%{grub2fontdir}/ter-u14b.pf2
%{grub2fontdir}/ter-u14n.pf2
%{grub2fontdir}/ter-u16b.pf2
%{grub2fontdir}/ter-u16n.pf2
%{grub2fontdir}/ter-u18b.pf2
%{grub2fontdir}/ter-u18n.pf2
%{grub2fontdir}/ter-u20b.pf2
%{grub2fontdir}/ter-u20n.pf2
%{grub2fontdir}/ter-u22b.pf2
%{grub2fontdir}/ter-u22n.pf2
%{grub2fontdir}/ter-u24b.pf2
%{grub2fontdir}/ter-u24n.pf2
%{grub2fontdir}/ter-u28b.pf2
%{grub2fontdir}/ter-u28n.pf2
%{grub2fontdir}/ter-u32b.pf2
%{grub2fontdir}/ter-u32n.pf2
%endif


%changelog
* Tue Jan  7 2020 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.48-2.1.4
- Update bitmapfonts2otb.py from Peng Wu
- Stop using shell=True in bitmapfonts2otb.py

* Tue Jan  7 2020 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.48-2.1.3
- Ship *.bdf as -legacy-bdf, *.pcf as -legacy-pcf

* Tue Jan  7 2020 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.48-2.1.2
- Use fonttosfnt to convert *.bdf to *.otb

* Tue Jan  7 2020 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.48-2.1.1
- Split off legacy pcf fonts into -legacy-x11 using fontforge

* Fri Jan  3 2020 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.48-2
- Stop shipping VGA fonts in grub subpackage
- Build OTB fonts for compatibility with pango >= 1.44 (#1748495)

* Tue Aug 27 2019 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.48-1
- Update to upstream release terminus-font-4.48
- Ship the Hebrew characters introduced by terminus-font-4.48

* Sat Jul 27 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.47-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.47-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sun Jan 27 2019 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.47-4
- Only build -grub2 subpackage when arch/dist actually has grub2
- Address and silence rpmlint warnings

* Tue Jan 15 2019 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.47-3
- Update to upstream release terminus-font-4.47

* Tue Jan 15 2019 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.46-3
- Continue shipping the 8bit versions of *.pcf files (#1664054)

* Tue Dec 18 2018 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.46-2
- Add grub2 subpackage with *.pf2 fonts

* Tue Dec 18 2018 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.46-1
- Update to terminus-font-4.46

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.40-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.40-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.40-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.40-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon May 16 2016 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.40-5
- Fix terminus-fonts-console README.fedora instructions on checking the initramfs.

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.40-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Jan 18 2016 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.40-3
- Fix spelling issue in %%description
- iconv README-BG from WINDOWS-1251 to utf-8

* Sun Jan 17 2016 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.40-2
- Update to terminus-font-4.40 (#1095285)

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.39-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Jul 10 2014 Jens Petersen <petersen@redhat.com> - 4.39-1
- update to 4.39

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.38-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Nov 28 2013 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.38-3
- Improve instructions for F18+ to console README.fedora (#1000491)

* Sat Nov 16 2013 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.38-2
- Add instructions for F18+ to terminus-fonts-console README.fedora (#1000491)

* Mon Sep 16 2013 Parag <paragn AT fedoraproject DOT org> - 4.38-1
- Update to new 4.38 version

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.36-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.36-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.36-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.36-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Sep 12 2011 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.36-1
- Update to terminus-font-4.36

* Sat May 21 2011 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.35-1
- Update to terminus-font-4.35
- Actually ship the size 18 fonts (upstream fix)

* Mon May  2 2011 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.34-1
- Update to terminus-font-4.34
- Remove patch for alt/ge1.diff (4.34 uses ge1 by default)

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.32-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Feb  1 2011 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.32-1
- Update to 4.32

* Fri Jul 16 2010 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.30-2
- Added License tag to -console subpackage.
- Added note about rebuilding initramfs after changing /etc/sysconfig/i18n.
- Changed URL, SourceN, PatchN to use new location at sourceforge.net.

* Fri Dec  4 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.30-1
- update to 4.30 release:
  - new size 22 (not very good)
  - 25 additional characters
  - various small fixes

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.28-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Mar 25 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.28-8
- Rebuild for Fedora 11 to pick up font autodeps (#491973)

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.28-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Feb 20 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.28-6
- fix fontpackages-devel requirement to >= 1.18 (for _fontdir ownership)

* Fri Feb 20 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.28-5
- Add information to the fontconfig file
- no need to %%dir %%{_fontdir} in fontpackages-devel >= 1.20
- Use %%{_sysconfdir} instead of /etc
- Change all %%define instances to %%global
- Drop filesystem requirement for F-10 and later
- Use macro for common parts of descriptions
- Remove unneeded Provides:
- drop unnecessary comment

* Thu Feb 19 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.28-4
- change catalog(ue) spelling to US English
- remove unnecessary macro definition of %%tarname
- properly define consolefontdir (no macros)

* Thu Feb 19 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.28-3
- generate fonts.dir at build time (bug 483589)

* Wed Feb 18 2009 Hans Ulrich Niedermann <hun@n-dimensional.de> - 4.28-2
- initial package for new Fedora Font Policy
